pub struct MakeConnectionRequest { /* private fields */ }Expand description
A request from the peer set to make an outbound connection.
This will only be sent when the peer set is under load from the rest of Cuprate or the peer set needs specific data that none of the currently connected peers have.