OutboundConnectionKeeper

Struct OutboundConnectionKeeper 

pub struct OutboundConnectionKeeper<Z: NetworkZone, A, C> {
    pub new_peers_tx: Sender<Client<Z>>,
    pub make_connection_rx: Receiver<MakeConnectionRequest>,
    pub address_book_svc: A,
    pub connector_svc: C,
    pub outbound_semaphore: Arc<Semaphore>,
    pub extra_peers: usize,
    pub config: P2PConfig<Z>,
    pub peer_type_gen: Bernoulli,
    pub peer_sync_callback: Option<PeerSyncCallback>,
}
The outbound connection count keeper.

This handles maintaining a minimum number of connections and making extra connections when needed, upto a maximum.

Fields

new_peers_tx: Sender<Client<Z>>

The pool of currently connected peers.

make_connection_rx: Receiver<MakeConnectionRequest>

The channel that tells us to make new extra outbound connections.

address_book_svc: A

The address book service

connector_svc: C

The service to connect to a specific peer.

outbound_semaphore: Arc<Semaphore>

A semaphore to keep the amount of outbound peers constant.

extra_peers: usize

The amount of peers we connected to because we needed more peers. If the outbound_semaphore is full, and we need to connect to more peers for blocks or because not enough peers are ready we add a permit to the semaphore and keep track here, upto a value in config.

config: P2PConfig<Z>

The p2p config.

peer_type_gen: Bernoulli

The Bernoulli distribution, when sampled will return true if we should connect to a gray peer or false if we should connect to a white peer.

This is weighted to the percentage given in config.

peer_sync_callback: Option<PeerSyncCallback>

A callback used to notify the syncer about peer sync state changes.

Implementations

Source

impl<Z, A, C> OutboundConnectionKeeper<Z, A, C>
where Z: NetworkZone, A: AddressBook<Z>, C: Service<ConnectRequest<Z>, Response = Client<Z>, Error = HandshakeError>, C::Future: Send + 'static,

pub fn new( config: P2PConfig<Z>, new_peers_tx: Sender<Client<Z>>, make_connection_rx: Receiver<MakeConnectionRequest>, address_book_svc: A, connector_svc: C, peer_sync_callback: Option<PeerSyncCallback>, ) -> Self

pub async fn run(self)

Runs the outbound connection count keeper.